export declare function eventBusFromArray(eventList: Array<string>): EventStore;
export declare class ForeignEventError extends Error {
    static errorText: string;
    constructor();
}
/**
 * generates event object with a _symbol key used as an identifier
 * to be used to unsubscribe.
 */
export declare function getEventObject(handler: () => void, token: Symbol): EventObject;
/**
 * used by the unsubscribe function returned from subscribe
 * function to clear the events store from a specific handler
 * through its Symbol.
 */
export declare function clearHandlerFromStore(eventName: EventName, keySymbol: Symbol, eventStore: EventStore): EventStore;
/**
 * extracts events array and excutes it to return the array after excution
 */
export declare enum EventActionsTypes {
    subscribe = "subscribe",
    unsubscribe = "unsubscribe",
    emit = "emit"
}
interface SubscribePayload {
    eventName: string;
    handler: VoidFn;
    token: Symbol;
}
interface UnsubscribePayload {
    eventName: string;
    token: Symbol;
}
interface EmitPayload {
    eventName: string;
}
declare type EventActionPayload = EmitPayload | SubscribePayload | UnsubscribePayload;
declare type EventAction<P extends EventActionPayload> = {
    type: EventActionsTypes;
    payload: P;
};
export declare function eventStoreReducer(state: EventStore, { type, payload }: EventAction<EventActionPayload>): EventStore;
export {};
